@@ -4,21 +4,36 @@
 """Public API of ALiCE Petisco Framework"""
 
 # Classes
-from petisco.application.application_config import ApplicationConfig
-from petisco.application.repository import Repository
-from petisco.application.service import Service
+
+from petisco.application.config.config import Config
+from petisco.application.interface_repository import IRepository
+from petisco.application.interface_service import IService
+from petisco.application.petisco import Petisco
 from petisco.application.singleton import Singleton
 from petisco.commands.command_handler import command_handler
-from petisco.controller.correlation_id import CorrelationId
-from petisco.controller.tokens.jwt_config import JwtConfig
-from petisco.domain.entities.client_id import ClientId
-from petisco.domain.entities.name import Name
-from petisco.domain.entities.user_id import UserId
-from petisco.domain.entities.value_object import ValueObject
+from petisco.domain.aggregate_roots.aggregate_root import AggregateRoot
+from petisco.domain.aggregate_roots.info_id import InfoId
+from petisco.domain.errors.empty_value_object_error import EmptyValueObjectError
+from petisco.domain.errors.exceed_length_limit_value_error_error import (
+    ExceedLengthLimitValueObjectError,
+)
+from petisco.domain.value_objects.name import Name
+from petisco.domain.value_objects.client_id import ClientId
+from petisco.domain.value_objects.user_id import UserId
+from petisco.domain.value_objects.correlation_id import CorrelationId
+from petisco.domain.value_objects.value_object import ValueObject
 from petisco.events.event_config import EventConfig
+from petisco.frameworks.interface_application import IApplication
 from petisco.logger.logging_based_logger import LoggingBasedLogger
 from petisco.logger.interface_logger import ILogger
 from petisco.persistence.interface_persistence_connector import IPersistenceConnector
+from petisco.security.token_decoder.interface_token_decoder import ITokenDecoder
+from petisco.security.token_decoder.token_decoder import TokenDecoder
+from petisco.security.token_manager.interface_token_manager import ITokenManager
+from petisco.security.token_manager.not_implemented_token_manager import (
+    NotImplementedTokenManager,
+)
+from petisco.security.token_manager.token_manager import TokenManager
 from petisco.use_case import UseCase
 from petisco.use_case import use_case_handler
 from petisco.controller.controller_handler import controller_handler
@@ -29,9 +44,8 @@ from petisco.events.interface_event_manager import IEventManager
 from petisco.events.not_implemented_event_manager import NotImplementedEventManager
 
 classes = [
-    "ApplicationConfig",
-    "Service",
-    "Repository",
+    "IService",
+    "IRepository",
     "UseCase",
     "use_case_handler",
     "controller_handler",
@@ -45,15 +59,50 @@ classes = [
     "IEventManager",
     "NotImplementedEventManager",
     "Singleton",
-    "JwtConfig",
+    "TokenManager",
+    "NotImplementedTokenManager",
+    "ITokenManager",
+    "TokenDecoder",
+    "ITokenDecoder",
     "IPersistenceConnector",
     "ValueObject",
     "Name",
     "ClientId",
     "UserId",
+    "InfoId",
     "EventConfig",
+    "AggregateRoot",
+    "Petisco",
+    "IApplication",
+    "Config",
+    "EmptyValueObjectError",
+    "ExceedLengthLimitValueObjectError",
 ]
 
+# Controllers & Use Cases
+from petisco.modules.environment.application.environment import environment
+from petisco.modules.environment.application.environment_provider import (
+    EnvironmentProvider,
+)
+from petisco.modules.environment.domain.environment_provider_error import (
+    EnvironmentProviderError,
+)
+from petisco.modules.healthcheck.application.healthcheck import healthcheck
+from petisco.modules.healthcheck.application.healthcheck_provider import (
+    HealthcheckProvider,
+)
+from petisco.modules.healthcheck.domain.persistence_error import PersistenceError
+
+controllers_and_use_cases = [
+    "environment",
+    "EnvironmentProvider",
+    "EnvironmentProviderError",
+    "healthcheck",
+    "HealthcheckProvider",
+    "PersistenceError",
+]
+
+
 # Constants
 from petisco.logger.interface_logger import (
     CRITICAL,
@@ -126,4 +175,12 @@ try:
 except (RuntimeError, ImportError):
     rabbitmq = []
 
-__all__ = classes + constants + flask + sqlalchemy + redis + rabbitmq
+__all__ = (
+    classes
+    + controllers_and_use_cases
+    + constants
+    + flask
+    + sqlalchemy
+    + redis
+    + rabbitmq
+)
