@@ -1,4 +1,5 @@
 from typing import List, Any
+import json
 
 from meiga import Result
 from meiga.decorators import meiga
@@ -30,12 +31,10 @@ class _UseCaseHandler:
             logging_types_blacklist = self.logging_types_blacklist
 
             def execute(self, *args, **kwargs):
-                correlation_id = kwargs.get("correlation_id")
+                info_id = kwargs.get("info_id")
 
                 log_message = LogMessage(
-                    layer="use_case",
-                    operation=f"{cls.__name__}",
-                    correlation_id=correlation_id,
+                    layer="use_case", operation=f"{cls.__name__}", info_id=info_id
                 )
 
                 log_message.message = f"Start"
@@ -49,7 +48,7 @@ class _UseCaseHandler:
                     ]
 
                     if loggable_kwargs:
-                        log_message.message = dict(loggable_kwargs)
+                        log_message.message = json.dumps(dict(loggable_kwargs))
                         self.logger.log(INFO, log_message.to_json())
 
                 result = self._run_execute(*args, **kwargs)
